<?php
$parse_uri = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );
require_once( $parse_uri[0] . 'wp-load.php' );


/**
 * Callback for Opauth
 * 
 * This file (callback.php) provides an example on how to properly receive auth response of Opauth.
 * 
 * Basic steps:
 * 1. Fetch auth response based on callback transport parameter in config.
 * 2. Validate auth response
 * 3. Once auth response is validated, your PHP app should then work on the auth response 
 *    (eg. registers or logs user in to your site, save auth data onto database, etc.)
 * 
 */


/**
 * Define paths
 */
define('CONF_FILE', dirname(__FILE__).'/'.'opauth.conf.php');
define('OPAUTH_LIB_DIR', dirname(dirname(__FILE__)).'/lib/Opauth/');

/**
* Load config
*/
if (!file_exists(CONF_FILE)) {
	trigger_error('Config file missing at '.CONF_FILE, E_USER_ERROR);
	exit();
}
require CONF_FILE;

/**
 * Instantiate Opauth with the loaded config but not run automatically
 */
require OPAUTH_LIB_DIR.'Opauth.php';
$Opauth = new Opauth( $config, false );

	
/**
* Fetch auth response, based on transport configuration for callback
*/
$response = null;
$auth_response = 'null';

switch($Opauth->env['callback_transport']) {
	case 'session':
		session_start();
		$response = $_SESSION['opauth'];
		unset($_SESSION['opauth']);
		break;
	case 'post':
		$response = unserialize(base64_decode( $_POST['opauth'] ));
		break;
	case 'get':
		$response = unserialize(base64_decode( $_GET['opauth'] ));
		break;
	default:
		echo '<strong style="color: red;">Error: </strong>Unsupported callback_transport.'."<br>\n";
		break;
}

/**
 * Check if it's an error callback
 */
if (array_key_exists('error', $response)) {
	$error_url = cjfm_string(cjfm_generate_url('page_register')).'social_login_error=access_denied&provider='.$response['error']['provider'];
	wp_redirect($error_url);
	exit;
}

/**
 * Auth response validation
 * 
 * To validate that the auth response received is unaltered, especially auth response that 
 * is sent through GET or POST.
 */
else{
	if (empty($response['auth']) || empty($response['timestamp']) || empty($response['signature']) || empty($response['auth']['provider']) || empty($response['auth']['uid'])) {
		$error_url = cjfm_string(cjfm_generate_url('page_register')).'social_login_error=invalid_auth&provider='.$response['error']['provider'];
		wp_redirect($error_url);
		exit;
		// echo '<strong style="color: red;">Invalid auth response: </strong>Missing key auth response components.'."<br>\n";
	} elseif (!$Opauth->validate(sha1(print_r($response['auth'], true)), $response['timestamp'], $response['signature'], $reason)) {
		$error_url = cjfm_string(cjfm_generate_url('page_register')).'social_login_error=invalid_auth_response&provider='.$response['error']['provider'].'&reason='.urlencode($reason);
		wp_redirect($error_url);
		//echo '<strong style="color: red;">Invalid auth response: </strong>'.$reason.".<br>\n";
	} else {

		$auth_response = 'ok';

		if($auth_response == 'ok'){
			$social_connect_info['cjfm_sprovider'] = $response['auth']['provider'];
			$social_connect_info['cjfm_suid'] = $response['auth']['uid'];
			cjfm_process_social_login($social_connect_info);
		}

		//echo '<strong style="color: green;">OK: </strong>Auth response is validated.'."<br>\n";

		/**
		 * It's all good. Go ahead with your application-specific authentication logic
		 */
	}
}


function cjfm_process_social_login($social_connect_info){
	global $wpdb, $current_user;
	$cjfm_suid = $social_connect_info['cjfm_suid'];
	$cjfm_sprovider = $social_connect_info['cjfm_sprovider'];

	$login_url = cjfm_generate_url('page_login');

	$check_existing = $wpdb->get_row("SELECT * FROM $wpdb->usermeta WHERE meta_key = 'cjfm_suid' AND meta_value = '{$cjfm_suid}'");

	if(is_user_logged_in()){
		update_user_meta($current_user->ID, 'cjfm_suid', $cjfm_suid);
		update_user_meta($current_user->ID, 'cjfm_sprovider', $cjfm_sprovider);
		wp_redirect( $login_url, $status = 302 );
		exit;
	}

	if(empty($check_existing)){
		$register_url = cjfm_string(cjfm_generate_url('page_register')).'cjfm_social_connect='.$cjfm_sprovider.'&uid='.$cjfm_suid;
		wp_redirect($register_url);
		exit;
	}else{
		$user_info = cjfm_user_info($check_existing->user_id);

		if(!isset($user_info['cjfm_rp'])){
			wp_redirect( $login_url, $status = 302 );
			exit;
		}

		
		$user_pass = base64_decode($user_info['cjfm_rp']);
		$creds = array();
		$creds['user_login'] = $user_info['user_login'];
		$creds['user_password'] = $user_pass;
		$creds['remember'] = true;
		$user = wp_signon( $creds, false );
		if ( !is_wp_error($user) ){
			update_user_meta($user->ID, 'cjfm_rp', base64_encode($user_pass));
			update_user_meta($user->ID, 'cjfm_last_login', time());
			update_user_meta($user->ID, 'cjfm_login_ip', cjfm_current_ip_address());
			$user_info = cjfm_user_info($user->ID);
			do_action('cjfm_login_done', $user_info);
			wp_redirect( $login_url, $status = 302 );
			exit;
		}

	}

}
